@@ -32,8 +32,6 @@ class DummyRcEvaluator(RcEvaluator):
 class TestConditionNodeBuilder:
     _edifact_format = EdifactFormat.UTILMD
     _edifact_format_version = EdifactFormatVersion.FV2104
-    _dummy_evaluatable_data = EvaluatableData(edifact_seed=dict())
-    _evaluator = DummyRcEvaluator(_dummy_evaluatable_data)
 
     _h_583 = Hint(condition_key="583", hint="[583] Hinweis: Verwendung der ID der Marktlokation")
     _h_584 = Hint(condition_key="584", hint="[584] Hinweis: Verwendung der ID der Messlokation")
@@ -47,7 +45,11 @@ class TestConditionNodeBuilder:
             TestConditionNodeBuilder._edifact_format_version,
             file_path=Path("unittests/resources_condition_hints/FV2104/Hints_FV2104_UTILMD.json"),
         )
-        inject.clear_and_configure(lambda binder: binder.bind(HintsProvider, _hints_provider))
+        inject.clear_and_configure(
+            lambda binder: binder.bind(HintsProvider, _hints_provider).bind(
+                RcEvaluator, DummyRcEvaluator(EvaluatableData(edifact_seed=dict()))
+            )
+        )
         yield
         inject.clear()
 
@@ -55,7 +57,7 @@ class TestConditionNodeBuilder:
         """Tests if condition node builder is initiated correctly."""
 
         condition_keys = ["501", "12", "903"]
-        condition_node_builder = ConditionNodeBuilder(condition_keys, self._evaluator)
+        condition_node_builder = ConditionNodeBuilder(condition_keys)
 
         assert condition_node_builder.hints_provider.edifact_format == self._edifact_format
         assert condition_node_builder.rc_evaluator.edifact_format_version == self._edifact_format_version
@@ -69,14 +71,14 @@ class TestConditionNodeBuilder:
         condition_keys = ["5", "1011"]
 
         with pytest.raises(ValueError) as excinfo:
-            _ = ConditionNodeBuilder(condition_keys, self._evaluator)
+            _ = ConditionNodeBuilder(condition_keys)
 
         assert "Condition key is not in valid number range." in str(excinfo.value)
 
     def test_build_hint_nodes(self, setup_and_teardown_injector):
         """Tests that hint nodes are build correctly."""
         condition_keys = ["584", "583"]
-        condition_node_builder = ConditionNodeBuilder(condition_keys, self._evaluator)
+        condition_node_builder = ConditionNodeBuilder(condition_keys)
         hint_nodes = condition_node_builder._build_hint_nodes()
         excepted_hints_nodes = {"583": self._h_583, "584": self._h_584}
         assert hint_nodes == excepted_hints_nodes
@@ -86,7 +88,7 @@ class TestConditionNodeBuilder:
         condition_keys = ["500"]
         # it is possible that a hint with [500] will be implemented in the future as not all hints are collected yet.
         # If test fails, look up if hint exist. And if hint list is completed take one that does not exist.
-        condition_node_builder = ConditionNodeBuilder(condition_keys, self._evaluator)
+        condition_node_builder = ConditionNodeBuilder(condition_keys)
         with pytest.raises(KeyError) as excinfo:
             _ = condition_node_builder._build_hint_nodes()
 
@@ -95,7 +97,7 @@ class TestConditionNodeBuilder:
     def test_build_unevaluated_format_constraint_nodes(self, setup_and_teardown_injector):
         """Tests that unevaluated format constraints nodes are build correctly."""
         condition_keys = ["907", "955"]
-        condition_node_builder = ConditionNodeBuilder(condition_keys, self._evaluator)
+        condition_node_builder = ConditionNodeBuilder(condition_keys)
         unevaluated_fc_nodes = condition_node_builder._build_unevaluated_format_constraint_nodes()
         expected_unevaluated_fc_nodes = {"907": self._ufc_907, "955": self._ufc_955}
         assert unevaluated_fc_nodes == expected_unevaluated_fc_nodes
@@ -118,7 +120,7 @@ class TestConditionNodeBuilder:
         )
 
         condition_keys = ["11", "78"]
-        condition_node_builder = ConditionNodeBuilder(condition_keys, self._evaluator)
+        condition_node_builder = ConditionNodeBuilder(condition_keys)
 
         evaluated_requirement_constraints = condition_node_builder._build_requirement_constraint_nodes()
 
@@ -135,7 +137,7 @@ class TestConditionNodeBuilder:
         )
 
         condition_keys = ["78", "907", "11", "583"]
-        condition_node_builder = ConditionNodeBuilder(condition_keys, self._evaluator)
+        condition_node_builder = ConditionNodeBuilder(condition_keys)
 
         evaluated_requirement_constraints = (
             condition_node_builder.requirement_content_evaluation_for_all_condition_keys()
